==> search-ui-container-v2.2.3-3.tar.gz: package/lib/runner/GraphQLNodeMap.js <==
/**
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * @format
 * 
 */
// flowlint ambiguous-object-type:error
'use strict';

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _inheritsLoose2 = _interopRequireDefault(require("@babel/runtime/helpers/inheritsLoose"));

var _wrapNativeSuper2 = _interopRequireDefault(require("@babel/runtime/helpers/wrapNativeSuper"));

function _createForOfIteratorHelper(o, allowArrayLike) { var it; if (typeof Symbol === "undefined" || o[Symbol.iterator] == null) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e) { throw _e; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = o[Symbol.iterator](); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e2) { didErr = true; err = _e2; }, f: function f() { try { if (!normalCompletion && it["return"] != null) it["return"](); } finally { if (didErr) throw err; } } }; }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

var _require = require('../core/CompilerError'),
    createUserError = _require.createUserError,
    createCompilerError = _require.createCompilerError;

var _require2 = require('./GraphQLASTUtils'),
    getName = _require2.getName;

var GraphQLNodeMap = /*#__PURE__*/function (_Map) {
  (0, _inheritsLoose2["default"])(GraphQLNodeMap, _Map);

  function GraphQLNodeMap() {
    return _Map.apply(this, arguments) || this;
  }

  GraphQLNodeMap.from = function from(nodes) {
    var result = new GraphQLNodeMap();

    var _iterator = _createForOfIteratorHelper(nodes),
        _step;

    try {
      for (_iterator.s(); !(_step = _iterator.n()).done;) {
        var node = _step.value;
        var name = getName(node);
        var prevNode = result.get(name);

        if (prevNode) {
          throw createUserError("Duplicate node named '".concat(name, "'"), null, [node, prevNode]);
        }

        result.set(name, node);
      }
    } catch (err) {
      _iterator.e(err);
    } finally {
      _iterator.f();
    }

    return result;
  };

  GraphQLNodeMap.fromSources = function fromSources(sources) {
    return GraphQLNodeMap.from(sources.nodes());
  };

  var _proto = GraphQLNodeMap.prototype;

  _proto.enforceGet = function enforceGet(name) {
    var node = this.get(name);

    if (!node) {
      throw createCompilerError("GraphQLNodeMap: expected to have a node named ".concat(name, "."));
    }

    return node;
  };

  return GraphQLNodeMap;
}( /*#__PURE__*/(0, _wrapNativeSuper2["default"])(Map));

module.exports = GraphQLNodeMap;

==> search-ui-container-v2.4.1-3.tar.gz: package/lib/runner/GraphQLNodeMap.js <==
/**
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * @format
 * 
 */
// flowlint ambiguous-object-type:error
'use strict';

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _createForOfIteratorHelper2 = _interopRequireDefault(require("@babel/runtime/helpers/createForOfIteratorHelper"));

var _inheritsLoose2 = _interopRequireDefault(require("@babel/runtime/helpers/inheritsLoose"));

var _wrapNativeSuper2 = _interopRequireDefault(require("@babel/runtime/helpers/wrapNativeSuper"));

var _require = require('../core/CompilerError'),
    createUserError = _require.createUserError,
    createCompilerError = _require.createCompilerError;

var _require2 = require('./GraphQLASTUtils'),
    getName = _require2.getName;

var GraphQLNodeMap = /*#__PURE__*/function (_Map) {
  (0, _inheritsLoose2["default"])(GraphQLNodeMap, _Map);

  function GraphQLNodeMap() {
    return _Map.apply(this, arguments) || this;
  }

  GraphQLNodeMap.from = function from(nodes) {
    var result = new GraphQLNodeMap();

    var _iterator = (0, _createForOfIteratorHelper2["default"])(nodes),
        _step;

    try {
      for (_iterator.s(); !(_step = _iterator.n()).done;) {
        var node = _step.value;
        var name = getName(node);
        var prevNode = result.get(name);

        if (prevNode) {
          throw createUserError("Duplicate node named '".concat(name, "'"), null, [node, prevNode]);
        }

        result.set(name, node);
      }
    } catch (err) {
      _iterator.e(err);
    } finally {
      _iterator.f();
    }

    return result;
  };

  GraphQLNodeMap.fromSources = function fromSources(sources) {
    return GraphQLNodeMap.from(sources.nodes());
  };

  var _proto = GraphQLNodeMap.prototype;

  _proto.enforceGet = function enforceGet(name) {
    var node = this.get(name);

    if (!node) {
      throw createCompilerError("GraphQLNodeMap: expected to have a node named ".concat(name, "."));
    }

    return node;
  };

  return GraphQLNodeMap;
}( /*#__PURE__*/(0, _wrapNativeSuper2["default"])(Map));

module.exports = GraphQLNodeMap;
